@@ -3,9 +3,10 @@
 #' This function prints skeleton versions of the required SimDesign functions
 #' to run simulations, complete with the correct inputs, class of outputs, and optional comments to
 #' help with the initial definitions. Use this at the start of your Monte Carlo simulation study. The
-#' recommended approach when using the \code{RStudio} IDE is to write the simulation template to two
-#' separate files for easier debugging/sourcing (this is the default when a \code{filename} is passed).
-#' For a didactic presentation of the package refer to Sigal and Chalmers (in press).
+#' recommended approach is to save the template to the hard-drive by passing a suitable file name.
+#' However, for larger simulations, as well as when using the \code{RStudio}, two
+#' separate files will often be easier for debugging/sourcing the simulation code (achieved by passing
+#' \code{singlefile = FALSE}. For a didactic presentation of the package refer to Sigal and Chalmers (2016).
 #'
 #' @param filename a character vector indicating whether the output should be saved to two respective files
 #'   containing the simulation design and the functional components, respectively. Using this option
@@ -16,8 +17,9 @@
 #' @param comments logical; include helpful comments? Default is \code{FALSE}
 #'
 #' @param singlefile logical; when \code{filename} is included, put output in one files? When \code{FALSE} the
-#'   output is saved to two separate files containing the functions and design definitions. Default is
-#'   \code{FALSE}
+#'   output is saved to two separate files containing the functions and design definitions. The two-file format
+#'   often makes organization and debugging slightly easier, especially for larger Monte Carlo simulations.
+#'   Default is \code{TRUE}
 #'
 #' @param summarise include \code{summarise} function? Default is \code{TRUE}
 #'
@@ -26,8 +28,8 @@
 #' @export SimFunctions
 #'
 #' @references
-#' Sigal, M. J., & Chalmers, R. P. (in press). Play it again: Teaching statistics with Monte
-#' Carlo simulation. \code{Journal of Statistics Education}.
+#' Sigal, M. J., & Chalmers, R. P. (2016). Play it again: Teaching statistics with Monte
+#' Carlo simulation. \code{Journal of Statistics Education, 24}(3), 136-156.
 #'
 #' @examples
 #'
@@ -36,14 +38,15 @@
 #'
 #'\dontrun{
 #'
-#' # write output to two files (recommended)
-#' SimFunctions('mysim')
+#' # write output to two files (recommended for larger MCSs)
+#' SimFunctions('mysim', singlefile = FALSE)
 #'
 #' # write output files to a single file with comments
-#' SimFunctions('mysim', singlefile = TRUE, comments = TRUE)
+#' SimFunctions('mysim', comments = TRUE)
 #' }
 #'
-SimFunctions <- function(filename = NULL, dir = getwd(), comments = FALSE, singlefile = FALSE, summarise = TRUE){
+SimFunctions <- function(filename = NULL, dir = getwd(), comments = FALSE,
+                         singlefile = TRUE, summarise = TRUE){
     LINE <- function()
         cat('#-------------------------------------------------------------------\n')
     HEAD <- function(){
@@ -85,8 +88,8 @@ SimFunctions <- function(filename = NULL, dir = getwd(), comments = FALSE, singl
     TAIL <- function(){
         LINE()
         if(comments) cat('\n### Run the simulation\n')
-        cat('\nresults <- runSimulation(design=Design, replications=1000, ')
-        cat(sprintf('\n    generate=Generate, analyse=Analyse%s',
+        cat('\nresults <- runSimulation(design=Design, replications=1000, generate=Generate, ')
+        cat(sprintf('\n                         analyse=Analyse%s',
                     if(summarise) ', summarise=Summarise)' else ')'))
         cat('\n\n')
     }
